from typing import Any

import abc


class TextProcessor(abc.ABC):
    """
    Abstract general class for any Text Processor

    Parameters
    ----------
    text : str
        The text on which we will perform various operations, processing or obtain
        results
    """

    def __init__(self, text: str):
        self.text = text

    @abc.abstractmethod
    def process(self) -> Any:
        pass
